@@ -1,20 +1,20 @@
-/* $Id: atkmm.h,v 1.3 2002/12/31 17:56:12 daniel Exp $ */
+/* $Id$ */
 
 /* atkmm - a C++ wrapper for the GLib toolkit
  *
  * Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -24,8 +24,10 @@
 
 #include <atkmm/action.h>
 #include <atkmm/component.h>
+#include <atkmm/document.h>
 #include <atkmm/editabletext.h>
 #include <atkmm/image.h>
+#include <atkmm/implementor.h>
 #include <atkmm/object.h>
 #include <atkmm/objectaccessible.h>
 #include <atkmm/relation.h>
