@@ -80,6 +80,7 @@
 #include "iconview.h"
 #include "image.h"
 #include "imagemenuitem.h"
+#include "infobar.h"
 #include "inputdialog.h"
 #include "invisible.h"
 #include "item.h"
@@ -260,6 +261,7 @@ GType gtk_icon_theme_get_type(void);
 GType gtk_icon_view_get_type(void);
 GType gtk_image_get_type(void);
 GType gtk_image_menu_item_get_type(void);
+GType gtk_info_bar_get_type(void);
 GType gtk_input_dialog_get_type(void);
 GType gtk_invisible_get_type(void);
 GType gtk_item_get_type(void);
@@ -456,6 +458,7 @@ namespace Gtk {  class IconTheme_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gtk {  class IconView_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Image_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class ImageMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class InfoBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class InputDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Invisible_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Item_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -652,6 +655,7 @@ void wrap_init()
   Glib::wrap_register(gtk_icon_view_get_type(), &Gtk::IconView_Class::wrap_new);
   Glib::wrap_register(gtk_image_get_type(), &Gtk::Image_Class::wrap_new);
   Glib::wrap_register(gtk_image_menu_item_get_type(), &Gtk::ImageMenuItem_Class::wrap_new);
+  Glib::wrap_register(gtk_info_bar_get_type(), &Gtk::InfoBar_Class::wrap_new);
   Glib::wrap_register(gtk_input_dialog_get_type(), &Gtk::InputDialog_Class::wrap_new);
   Glib::wrap_register(gtk_invisible_get_type(), &Gtk::Invisible_Class::wrap_new);
   Glib::wrap_register(gtk_item_get_type(), &Gtk::Item_Class::wrap_new);
@@ -836,6 +840,7 @@ void wrap_init()
   Gtk::IconView::get_type();
   Gtk::Image::get_type();
   Gtk::ImageMenuItem::get_type();
+  Gtk::InfoBar::get_type();
   Gtk::InputDialog::get_type();
   Gtk::Invisible::get_type();
   Gtk::Item::get_type();
