@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc 875 2007-07-22 19:49:03Z murrayc $ */
+/* $Id$ */
 
 /* generate_defs_gtk.cc
  *
@@ -12,9 +12,9 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -22,12 +22,9 @@
 #include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkprinter.h>
-#include <gtk/gtkprintjob.h>
 
 #if !defined(G_OS_WIN32)
-#include <gtk/gtkpagesetupunixdialog.h>
-#include <gtk/gtkprintunixdialog.h>
+#include <gtk/gtkunixprint.h>
 #endif /* G_OS_WIN32 */
 
 
@@ -77,6 +74,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_ACCEL_LABEL )
             << get_defs( GTK_TYPE_ACTION )
             << get_defs( GTK_TYPE_ACTION_GROUP )
+            << get_defs( GTK_TYPE_ACTIVATABLE )
             << get_defs( GTK_TYPE_ADJUSTMENT )
             << get_defs( GTK_TYPE_ALIGNMENT)
             << get_defs( GTK_TYPE_ARROW )
@@ -112,6 +110,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_CURVE )
             << get_defs( GTK_TYPE_DIALOG )
             << get_defs( GTK_TYPE_DRAWING_AREA )
+            << get_defs( GTK_TYPE_EDITABLE )
             << get_defs( GTK_TYPE_ENTRY )
             << get_defs( GTK_TYPE_ENTRY_COMPLETION )
             << get_defs( GTK_TYPE_EVENT_BOX )
@@ -129,6 +128,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_HANDLE_BOX )
             << get_defs( GTK_TYPE_ICON_THEME )
             << get_defs( GTK_TYPE_IMAGE )
+            << get_defs( GTK_TYPE_IMAGE_MENU_ITEM )
             << get_defs( GTK_TYPE_INPUT_DIALOG )
             << get_defs( GTK_TYPE_INVISIBLE )
             << get_defs( GTK_TYPE_ITEM )
@@ -148,14 +148,17 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_NOTEBOOK )
             << get_defs( GTK_TYPE_OBJECT )
             << get_defs( GTK_TYPE_OPTION_MENU )
+            << get_defs( GTK_TYPE_ORIENTABLE ) 
             << get_defs( GTK_TYPE_PANED )
             << get_defs( GTK_TYPE_PIXMAP )
 #if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_PLUG )
 #endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_PREVIEW )
+#if !defined(G_OS_WIN32)
 	    << get_defs( GTK_TYPE_PRINTER )
 	    << get_defs( GTK_TYPE_PRINT_JOB )
+#endif /* G_OS_WIN32 */
 	    << get_defs( GTK_TYPE_PRINT_OPERATION )
 	    << get_defs( GTK_TYPE_PRINT_OPERATION_PREVIEW )
 #if !defined(G_OS_WIN32)
@@ -208,6 +211,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_TOOLTIP )
             << get_defs( GTK_TYPE_TOOLTIPS )
             << get_defs( GTK_TYPE_TREE_SELECTION )
+            << get_defs( GTK_TYPE_TREE_MODEL ) 
             << get_defs( GTK_TYPE_TREE_MODEL_FILTER )            
             << get_defs( GTK_TYPE_TREE_STORE )
             << get_defs( GTK_TYPE_TREE_VIEW )
